@@ -23,13 +23,8 @@
 #define NODE_VERSION_H
 
 #define NODE_MAJOR_VERSION 0
-#define NODE_MINOR_VERSION 8
-#define NODE_PATCH_VERSION 17
-
-#ifndef NODE_TAG
-# define NODE_TAG ""
-#endif
-
+#define NODE_MINOR_VERSION 9
+#define NODE_PATCH_VERSION 1
 #define NODE_VERSION_IS_RELEASE 1
 
 #ifndef NODE_STRINGIFY
@@ -40,13 +35,11 @@
 #if NODE_VERSION_IS_RELEASE
 # define NODE_VERSION_STRING  NODE_STRINGIFY(NODE_MAJOR_VERSION) "." \
                               NODE_STRINGIFY(NODE_MINOR_VERSION) "." \
-                              NODE_STRINGIFY(NODE_PATCH_VERSION)     \
-                              NODE_TAG
+                              NODE_STRINGIFY(NODE_PATCH_VERSION)
 #else
 # define NODE_VERSION_STRING  NODE_STRINGIFY(NODE_MAJOR_VERSION) "." \
                               NODE_STRINGIFY(NODE_MINOR_VERSION) "." \
-                              NODE_STRINGIFY(NODE_PATCH_VERSION)     \
-                              NODE_TAG "-pre"
+                              NODE_STRINGIFY(NODE_PATCH_VERSION) "-pre"
 #endif
 
 #define NODE_VERSION "v" NODE_VERSION_STRING
